@@ -10,8 +10,6 @@
 #include <ctype.h>
 #include <iostream>
 #include <unistd.h>  //  for access(), etc.  BCG
-#include "snprintf.h"
-#include "general.h"
 #ifndef NULL
 #define NULL 0
 #endif
@@ -141,28 +139,29 @@ Listed from weakest to strongest:
   //  Merge in the system resource database.
   char rfilename[2048];
   int result;
+  const int rlen = sizeof rfilename;
 
   // Get the app-defaults
   result = snprintf(rfilename, sizeof rfilename, "/etc/X11/app-defaults/%s",
     XrmQuarkToString(_class));
-  if (rfilename != NULL)
+  if (result >= 0 && result < rlen)
     XrmCombineFileDatabase (rfilename, &_db, 1);
   result = snprintf(rfilename, sizeof rfilename, "/usr/lib/X11/app-defaults/%s",
     XrmQuarkToString(_class));
-  if (result >= 0 && result < sizeof rfilename)
+  if (result >= 0 && result < rlen)
     XrmCombineFileDatabase (rfilename, &_db, 1);
   result = snprintf(rfilename, sizeof rfilename, "/usr/X11R6/lib/X11/app-defaults/%s",
     XrmQuarkToString(_class));
-  if (result >= 0 && result < sizeof rfilename)
+  if (result >= 0 && result < rlen)
     XrmCombineFileDatabase (rfilename, &_db, 1);
   //  Try a few more, for SunOS/Solaris folks.
   result = snprintf(rfilename, sizeof rfilename, "/usr/openwin/lib/X11/app-defaults/%s",
     XrmQuarkToString(_class));
-  if (result >= 0 && result < sizeof rfilename)
+  if (result >= 0 && result < rlen)
     XrmCombineFileDatabase (rfilename, &_db, 1);
   result = snprintf(rfilename, sizeof rfilename, "/usr/local/X11R6/lib/X11/app-defaults/%s",
       XrmQuarkToString(_class));
-  if (result >= 0 && result < sizeof rfilename)
+  if (result >= 0 && result < rlen)
     XrmCombineFileDatabase (rfilename, &_db, 1);
 
   //  Now, check for an XOSView file in the XAPPLRESDIR directory...
