@@ -3,9 +3,7 @@
 //
 //  This file may be distributed under terms of the GPL
 //
-//
-// $Id$
-//
+
 #include <stdlib.h>		/*  For atoi().  */
 #include "intmeter.h"
 #include "kernel.h"
@@ -26,6 +24,9 @@ IntMeter::IntMeter( XOSView *parent,
               dolegends, dousedlegends ) {
   for ( int i = 0 ; i < 16 ; i++ )
     irqs_[i] = lastirqs_[i] = 0;
+  if (!BSDIntrInit()) {
+    disableMeter();
+  }
 }
 
 IntMeter::~IntMeter( void ){
@@ -44,9 +45,11 @@ void IntMeter::checkevent( void ){
 
 void IntMeter::checkResources( void ){
   BitMeter::checkResources();
-  onColor_  = parent_->allocColor( parent_->getResource( "intOnColor" ) );
-  offColor_ = parent_->allocColor( parent_->getResource( "intOffColor" ) );
-  priority_ = atoi( parent_->getResource( "intPriority" ) );
+  if (!disabled_) {
+    onColor_  = parent_->allocColor( parent_->getResource( "intOnColor" ) );
+    offColor_ = parent_->allocColor( parent_->getResource( "intOffColor" ) );
+    priority_ = atoi( parent_->getResource( "intPriority" ) );
+  }
 }
 
 void 
