@@ -7,8 +7,6 @@
 #include <iostream>
 #include <fstream>
 #include <stdlib.h>
-#include "snprintf.h"
-#include "general.h"
 #include "fieldmeter.h"
 #include "xosview.h"
 
