@@ -1,11 +1,9 @@
 //
-//  Copyright (c) 1994, 1995, 2002 by Mike Romberg ( romberg@fsl.noaa.gov )
+//  Copyright (c) 1994, 1995, 2002, 2006 by Mike Romberg ( mike.romberg@noaa.gov )
 //
 //  This file may be distributed under terms of the GPL
 //
-//
-// $Id$
-//
+
 #include "MeterMaker.h"
 #include "xosview.h"
 
@@ -18,6 +16,8 @@
 #include "serialmeter.h"
 #include "loadmeter.h"
 #include "btrymeter.h"
+#include "wirelessmeter.h"
+#include <fstream>
 #include "diskmeter.h"
 #include "raidmeter.h"
 #include "lmstemp.h"
@@ -25,6 +25,10 @@
 
 #include <stdlib.h>
 
+#include <sstream>
+#include <iomanip>
+
+using namespace std;
 
 MeterMaker::MeterMaker(XOSView *xos){
   _xos = xos;
@@ -37,13 +41,53 @@ void MeterMaker::makeMeters(void){
 
   // Standard meters (usually added, but users could turn them off)
   if (_xos->isResourceTrue("cpu")){
-    int cpuCount = CPUMeter::countCPUs();
-    int start = (cpuCount == 0) ? 0 : 1;
-    for (int i = start ; i <= cpuCount ; i++)
-      push(new CPUMeter(_xos, CPUMeter::cpuStr(i)));
+    bool single, both, all;
+    unsigned int cpuCount = CPUMeter::countCPUs();
+
+    single = (strncmp(_xos->getResource("cpuFormat"), "single", 2) == 0);
+    both = (strncmp(_xos->getResource("cpuFormat"), "both", 2) == 0);
+    all = (strncmp(_xos->getResource("cpuFormat"), "all", 2) == 0);
+
+    if (strncmp(_xos->getResource("cpuFormat"), "auto", 2) == 0) {
+      if (cpuCount == 1 || cpuCount > 4) {
+	single = true;
+      } else {
+	all = true;
+      }
+    }
+
+    if (single || both)
+      push(new CPUMeter(_xos, CPUMeter::cpuStr(0)));
+
+    if (all || both) {
+      for (unsigned int i = 1; i <= cpuCount; i++)
+	push(new CPUMeter(_xos, CPUMeter::cpuStr(i)));
+    }
   }
   if (_xos->isResourceTrue("mem"))
     push(new MemMeter(_xos));
+  if (_xos->isResourceTrue("disk"))
+      push(new DiskMeter(_xos, atof(_xos->getResource("diskBandwidth"))));
+
+  // check for the wireless meter
+static const char WLFILENAME[] = "/proc/net/wireless";
+ifstream stats( WLFILENAME );
+if ( stats ) {
+  if (_xos->isResourceTrue("wireless")){
+    int wirelessCount = WirelessMeter::countdevices();
+    int start = (wirelessCount == 0) ? 0 : 1;
+	if (wirelessCount != 0) {
+    for (int i = start ; i <= wirelessCount ; i++)
+      push(new WirelessMeter(_xos, i, WirelessMeter::wirelessStr(i)));
+  } } }
+
+  // check for the RAID meter
+  if (_xos->isResourceTrue("RAID")){
+    int RAIDCount = atoi(_xos->getResource("RAIDdevicecount"));
+    for (int i = 0 ; i < RAIDCount ; i++)
+      push(new RAIDMeter(_xos, i));
+  }
+
   if (_xos->isResourceTrue("swap"))
     push(new SwapMeter(_xos));
 
@@ -54,17 +98,36 @@ void MeterMaker::makeMeters(void){
   if (_xos->isResourceTrue("net"))
     push(new NetMeter(_xos, atof(_xos->getResource("netBandwidth"))));
 
-  if (_xos->isResourceTrue("disk"))
-      push(new DiskMeter(_xos, atof(_xos->getResource("diskBandwidth"))));
+  // check for the NFS mesters
+  if (_xos->isResourceTrue("NFSDStats")){
+      push(new NFSDStats(_xos));
+  }
+  if (_xos->isResourceTrue("NFSStats")){
+      push(new NFSStats(_xos));
+  }
+
 
   // check for the serial meters.
 #if defined (__arm__) || defined(__mc68000__) || defined(__powerpc__) || defined(__sparc__) || defined(__s390__) || defined(__s390x__)
   /* these architectures have no ioperm() */
 #else
   for (int i = 0 ; i < SerialMeter::numDevices() ; i++)
-    if (_xos->isResourceTrue(SerialMeter::getResourceName(
-      (SerialMeter::Device)i)))
-        push(new SerialMeter(_xos, (SerialMeter::Device)i));
+      {
+      bool ok ;  unsigned long val ;
+      const char *res = SerialMeter::getResourceName((SerialMeter::Device)i);
+      if ( !(ok = _xos->isResourceTrue(res)) )
+          {
+          std::istringstream is(_xos->getResource(res));
+          is >> std::setbase(0) >> val;
+          if (!is)
+              ok = false;
+          else
+              ok = val & 0xFFFF;
+          }
+
+      if ( ok )
+          push(new SerialMeter(_xos, (SerialMeter::Device)i));
+      }
 #endif
 
   // check for the interrupt meter
@@ -76,16 +139,9 @@ void MeterMaker::makeMeters(void){
   }
 
   // check for the battery meter
-  if (_xos->isResourceTrue("battery"))
+  if (_xos->isResourceTrue("battery") && BtryMeter::has_source())
     push(new BtryMeter(_xos));
 
-  // check for the RAID meter
-  if (_xos->isResourceTrue("RAID")){
-    int RAIDCount = atoi(_xos->getResource("RAIDdevicecount"));
-    for (int i = 0 ; i < RAIDCount ; i++)
-      push(new RAIDMeter(_xos, i));
-  }
-
   // check for the LmsTemp meter
   if (_xos->isResourceTrue("lmstemp")){
     char caption[80];
@@ -102,11 +158,4 @@ void MeterMaker::makeMeters(void){
       push(new LmsTemp(_xos, res, lab, caption));
     }
   }
-  // check for the NFS mesters
-  if (_xos->isResourceTrue("NFSDStats")){
-      push(new NFSDStats(_xos));
-  }
-  if (_xos->isResourceTrue("NFSStats")){
-      push(new NFSStats(_xos));
-  }
 }
