@@ -1,25 +1,23 @@
 //
-//  Copyright (c) 1994, 1995 by Mike Romberg ( romberg@fsl.noaa.gov )
+//  Copyright (c) 1994, 1995, 2006 by Mike Romberg ( mike.romberg@noaa.gov )
 //
 //  This file may be distributed under terms of the GPL
 //
-//
-// $Id$
-//
+
 #include "intmeter.h"
 #include "xosview.h"
 #include "cpumeter.h"
 #include <fstream>
 #include <sstream>
+#include <map>
 #include <stdlib.h>
-#ifdef __alpha__
-#include <asm/irq.h>
-#endif
 
 
 static const char *INTFILE     = "/proc/interrupts";
 static const char *VERSIONFILE = "/proc/version";
 
+std::map<int,int> realintnum;
+
 IntMeter::IntMeter( XOSView *parent, int cpu)
   : BitMeter( parent, "INTS", "", 1,
               0, 0 ), _cpu(cpu), _old(true) {
@@ -63,12 +61,10 @@ float IntMeter::getLinuxVersion(void) {
       exit(1);
     }
 
-    char buffer[128];
-    vfile >> buffer >> buffer >> buffer;
-    *strrchr(buffer, '.') = '\0';
-    std::istringstream is(std::string(buffer, 128));
-    float rval = 0.0;
-    is >> rval;
+    std::string dump;
+    float rval;
+    vfile >> dump >> dump; // Drop the first two words
+    vfile >> rval; // Drops everything but #.# (float regex)
 
     return rval;
 }
@@ -80,6 +76,7 @@ int IntMeter::countCPUs(void) {
 void IntMeter::getirqs( void ){
   std::ifstream intfile( INTFILE );
   int intno, count;
+  int	idx;
 
   if ( !intfile ){
     std::cerr <<"Can not open file : " <<INTFILE << std::endl;
@@ -90,7 +87,8 @@ void IntMeter::getirqs( void ){
       intfile.ignore(1024, '\n');
 
   while ( !intfile.eof() ){
-    intfile >>intno;
+    intfile >> idx;
+    intno = realintnum[idx];
     if(intno>=numBits())
     	updateirqcount(intno,false);
     if (!intfile) break;
@@ -114,7 +112,15 @@ void IntMeter::updateirqcount( int n, bool init ){
    int old_bits=numBits();
    setNumBits(n+1);
    std::ostringstream os;
-   os << "INTs (0-" << (n) << ")" << std::ends;
+
+   os << "INTs (0-15" ;
+   for (std::map<int,int>::const_iterator it = realintnum.upper_bound(15),
+                                          end = realintnum.end();
+                                          it != end; ++it) {
+         os << ", " << it->first ;
+   }
+   os << ")" << std::ends;
+
    legend(os.str().c_str());
    unsigned long *old_irqs_=irqs_, *old_lastirqs_=lastirqs_;
    irqs_=new unsigned long[n+1];
@@ -122,7 +128,7 @@ void IntMeter::updateirqcount( int n, bool init ){
    /* If we are in init, set it to zero,
     * otherwise copy over the old set */
    if( init ) {
-	   for( int i=0; i < n; i++)
+	   for( int i=0; i < numBits(); i++)
 		irqs_[i]=lastirqs_[i]=0;
    }
    else {
@@ -146,22 +152,34 @@ void IntMeter::updateirqcount( int n, bool init ){
  */
 void IntMeter::initirqcount( void ){
   std::ifstream intfile( INTFILE );
-  int intno;
+  int intno = 0;
+  int i, idx;
 
   if ( !intfile ){
     std::cerr <<"Can not open file : " <<INTFILE << std::endl;
     exit( 1 );
   }
 
-  if (!_old)
-      intfile.ignore(1024, '\n');
+  if (!_old) {
+    for (i=0; i<16; i++)
+      realintnum[i] = i;
+    intfile.ignore(1024, '\n');
+  }
 
   /* just looking for the highest number interrupt that
    * is in use, ignore the rest of the data
    */
+  idx = 16;
   while ( !intfile.eof() ){
-    intfile >>intno;
+    intfile >> i;
+    /* break when reaching non-numeric special interrupts */
     if (!intfile) break;
+    if (i < 16)
+	intno = i;
+    else {
+	intno = idx;
+	realintnum[i] = idx++;
+    }
     intfile.ignore(1024, '\n');
   }
   updateirqcount(intno, true);
