@@ -19,17 +19,21 @@
 #include <dirent.h>
 #include <sys/stat.h>
 
-static const char PROC_SENSORS[] = "/proc/sys/dev/sensors";
+static const char PROC_SENSORS_24[] = "/proc/sys/dev/sensors";
+static const char PROC_SENSORS_26[] = "/sys/class/hwmon";
 
 LmsTemp::LmsTemp( XOSView *parent, const char *filename, const char *label,
 		 const char *caption)
   : FieldMeter( parent, 3, label, caption, 1, 1, 0 ){
-    if(!checksensors(filename)) {
-	std::cerr <<"Can not find file : " <<PROC_SENSORS <<"/*/" << filename
-          << std::endl;
-    	parent_->done(1);
+    if(!checksensors(1, PROC_SENSORS_24, filename)) {
+	if(!checksensors(0, PROC_SENSORS_26, filename)) {
+	    std::cerr <<"Can not find file : " <<PROC_SENSORS_24 <<"/*/" << filename
+		      << " or " <<PROC_SENSORS_26 <<"/*/device/" << filename
+		      << std::endl;
+	    parent_->done(1);
+	}
     }
-    char *p;
+    const char *p;
     if ((p = strrchr(caption,'/')) != 0)
       _highest = atoi(p+1);
     else
@@ -40,14 +44,14 @@ LmsTemp::~LmsTemp( void ){
 }
 
 /* this part is adapted from ProcMeter3.2 */
-int  LmsTemp::checksensors(const char* filename)
+int  LmsTemp::checksensors(int isproc, const char *dir, const char* filename)
 {
   bool found = false;
   DIR *d1, *d2;
   struct dirent *ent1, *ent2;
   struct stat buf;
 
-  d1=opendir(PROC_SENSORS);
+  d1=opendir(dir);
   if(!d1)
     return false;
   else
@@ -61,7 +65,10 @@ int  LmsTemp::checksensors(const char* filename)
 	  if(!strncmp(ent1->d_name,"..", 2))
 	    continue;
 
-	  snprintf(dirname, 64, "%s/%s",PROC_SENSORS ,ent1->d_name);
+	  snprintf(dirname, 64, "%s/%s",dir ,ent1->d_name);
+	  if (!isproc)
+	    strncat(dirname, "/device", sizeof(dirname) - strlen(dirname) - 1);
+
 	  if(stat(dirname,&buf)==0 && S_ISDIR(buf.st_mode))
 	    {
 	      d2=opendir(dirname);
@@ -78,9 +85,13 @@ int  LmsTemp::checksensors(const char* filename)
 		      if(stat(f,&buf)!=0 || !S_ISREG(buf.st_mode))
 			continue;
 
-		      if(!strncmp(ent2->d_name, filename, strlen(filename)))
+		      if((isproc && !strncmp(ent2->d_name, filename, strlen(filename))) ||
+			 (!isproc && !strncmp(ent2->d_name, filename, strlen(filename)) && !strncmp(ent2->d_name+strlen(filename), "_input", 6)))
 			{
+			  if (!isproc)
+			      f[strlen(f)-6] = '\0';
 			  strcpy(_filename, f);
+			  _isproc = isproc;
 			  found = true;
 			  break;
 			}
@@ -137,17 +148,47 @@ void LmsTemp::checkevent( void ){
 //
 
 void LmsTemp::getlmstemp( void ){
-  std::ifstream file( _filename );
+  // dummy, high changed from integer to double to allow it to display
+  // the full value, unfit for an int. (See Debian bug #183695)
+  double dummy, high;
 
-  if ( !file ){
-    std::cerr <<"Can not open file : " <<file << std::endl;
-    parent_->done(1);
-    return;
+  if (_isproc) {
+    std::ifstream file( _filename );
+
+    if ( !file ){
+	std::cerr <<"Can not open file : " <<file << std::endl;
+	parent_->done(1);
+	return;
+    }
+
+    file >> high >> dummy >> fields_[0];
+  }
+  else {
+      char f[128], *p;
+      strcpy(f, _filename);
+      p = f+strlen(f);
+
+      strcpy(p, "_input");
+      std::ifstream file1(f);
+      if ( !file1 ){
+	  std::cerr <<"Can not open file : " <<file1 << std::endl;
+	  parent_->done(1);
+	  return;
+      }
+      file1 >> fields_[0];
+      
+      strcpy(p, "_max");
+      std::ifstream file2(f);
+      if ( !file2 ){
+	  std::cerr <<"Can not open file : " <<file2 << std::endl;
+	  parent_->done(1);
+	  return;
+      }
+      file2 >> high;
+      high /= 1000; fields_[0] /= 1000;
   }
 
-  double dummy, high;
   total_ = _highest;  // Max temp
-  file >> high >> dummy >> fields_[0];
   fields_[1] = high - fields_[0];
   if(fields_[1] <= 0) {	// alarm
     fields_[1] = 0;
