@@ -1,8 +1,8 @@
-//  
-//  Copyright (c) 2000 by Leopold Toetsch <lt@toetsch.at>
+//
+//  Copyright (c) 2000, 2006 by Leopold Toetsch <lt@toetsch.at>
 //
 //  File based on btrymeter.* by
-//  Copyright (c) 1997 by Mike Romberg ( romberg@fsl.noaa.gov )
+//  Copyright (c) 1997 by Mike Romberg ( mike.romberg@noaa.gov )
 //
 //  This file may be distributed under terms of the GPL
 //
@@ -21,17 +21,18 @@ public:
 	  const char * caption);
   ~LmsTemp( void );
 
-  const char *name( void ) const { return "LmsTemp"; }  
+  const char *name( void ) const { return "LmsTemp"; }
   void checkevent( void );
 
   void checkResources( void );
 protected:
 
   void getlmstemp( void );
-  int  checksensors(const char* filename);
+  int  checksensors(int isproc, const char *dir, const char* filename);
 private:
   char _filename[80];
   int _highest;
+  int _isproc;
 };
 
 
