@@ -1,18 +1,19 @@
 //
-//  Copyright (c) 1994, 1995, 2006 by Mike Romberg ( mike.romberg@noaa.gov )
+//  Copyright (c) 1994, 1995, 2006, 2008 by Mike Romberg ( mike.romberg@noaa.gov )
 //
 //  This file may be distributed under terms of the GPL
 //
 //  Most of this code was written by Werner Fink <werner@suse.de>.
 //  Only small changes were made on my part (M.R.)
 //
-// $Id$
-//
+
 #include "loadmeter.h"
 #include "xosview.h"
+#include "cpumeter.h"
 #include <fstream>
 #include <sstream>
 #include <stdlib.h>
+#include <math.h>
 
 static const char LOADFILENAME[] = "/proc/loadavg";
 static const char SPEEDFILENAME[] = "/proc/cpuinfo";
@@ -44,8 +45,19 @@ void LoadMeter::checkResources( void ){
   dodecay_ = parent_->isResourceTrue( "loadDecay" );
   SetUsedFormat (parent_->getResource("loadUsedFormat"));
 
-  warnThreshold = atoi (parent_->getResource("loadWarnThreshold"));
-  critThreshold = atoi (parent_->getResource("loadCritThreshold"));
+  const char *warn = parent_->getResource("loadWarnThreshold");
+  if (strncmp(warn, "auto", 2) == 0) {
+      warnThreshold = CPUMeter::countCPUs();
+  } else {
+      warnThreshold = atoi(warn);
+  }
+
+  const char *crit = parent_->getResource("loadCritThreshold");
+  if (strncmp(crit, "auto", 2) == 0) {
+      critThreshold = warnThreshold * 4;
+  } else {
+      critThreshold = atoi(crit);
+  }
 
   do_cpu_speed  = parent_->isResourceTrue( "loadCpuSpeed" );
 
@@ -73,10 +85,7 @@ void LoadMeter::checkevent( void ){
         XOSDEBUG("SPEED: %d\n",cur_cpu_speed_);
         legnd << "PROCS/MIN" << " " << cur_cpu_speed_ << " MHz"<< std::ends;
             legend( legnd.str().c_str() );
-        if (dolegends_) {
-                        drawlegend();
-                        parent_->reallydraw();
-                }
+	drawlegend();
      }
   }
 
@@ -107,7 +116,7 @@ void LoadMeter::getloadinfo( void ){
     if ( alarmstate == 1 ) setfieldcolor( 0, warnloadcol_ );
     else
     /* if alarmstate == 2 */ setfieldcolor( 0, critloadcol_ );
-    if (dolegends_) drawlegend();
+    drawlegend();
     lastalarmstate = alarmstate;
   }
 
@@ -125,7 +134,7 @@ void LoadMeter::getloadinfo( void ){
   setUsed(fields_[0], (float) 1.0);
 }
 // just check /proc/cpuinfo for the speed of cpu0
-// (be ignorant on multi-cpus being on different speeds)
+// (average multi-cpus on different speeds)
 // display is intended mainly for laptops ...
 // (yes - i know about devices/system/cpu/cpu0/cpufreq )
 void LoadMeter::getspeedinfo( void ){
@@ -137,6 +146,9 @@ void LoadMeter::getspeedinfo( void ){
   std::string argname;
   std::string argval;
 
+  unsigned int total_cpu = 0;
+  unsigned int ncpus = 0;
+
   speedinfo.open(SPEEDFILENAME );
   while ( speedinfo.good() ) {
     argname.clear();
@@ -147,11 +159,17 @@ void LoadMeter::getspeedinfo( void ){
 
     if ( argname.substr(0,7) == "cpu MHz" ) {
         //XOSDEBUG("SPEED: %s\n",argval.c_str() );
-        old_cpu_speed_ = cur_cpu_speed_;
-        cur_cpu_speed_ = atoi(argval.c_str());
-        break;
+        total_cpu += atoi(argval.c_str());
+	ncpus++;
     }
   }
+
+  old_cpu_speed_ = cur_cpu_speed_;
+  if (ncpus > 0)
+    cur_cpu_speed_ = total_cpu / ncpus;
+  else
+    cur_cpu_speed_ = 0;
+
   speedinfo.close(); speedinfo.clear();
 
 }
