@@ -1,11 +1,9 @@
-//  
-//  Copyright (c) 1994, 1995 by Mike Romberg ( romberg@fsl.noaa.gov )
+//
+//  Copyright (c) 1994, 1995, 2006 by Mike Romberg ( mike.romberg@noaa.gov )
 //
 //  This file may be distributed under terms of the GPL
 //
-//
-// $Id$
-//
+
 #ifndef _MEMMETER_H_
 #define _MEMMETER_H_
 
@@ -16,7 +14,7 @@ public:
   MemMeter( XOSView *parent );
   ~MemMeter( void );
 
-  const char *name( void ) const { return "MemMeter"; }  
+  const char *name( void ) const { return "MemMeter"; }
   void checkevent( void );
 
   void checkResources( void );
@@ -28,10 +26,10 @@ private:
 
   class LineInfo {
   public:
-    LineInfo(const char *id, float *val) 
+    LineInfo(const char *id, double *val)
       { _line = -1; _id = id; _val = val; _idlen = strlen(_id); }
     LineInfo(void) {};
-    
+
     int line(void) { return _line; }
     void line(int l) { _line = l; }
     const char *id(void) { return _id; }
@@ -43,9 +41,9 @@ private:
     int _line;
     const char *_id;
     int _idlen;
-    float *_val;
+    double *_val;
   };
-  
+
   LineInfo *_MIlineInfos;
   int _numMIlineInfos;
 
