@@ -3,9 +3,7 @@
 //
 //  This file may be distributed under terms of the GPL
 //
-//
-// $Id$
-//
+
 #ifndef _NETMETER_H_
 #define _NETMETER_H_
 
@@ -31,7 +29,7 @@ private:
   int _ipsock;
   Timer _timer;
   unsigned long long _lastBytesIn, _lastBytesOut;
-  char *_netfilename;
+  const char *_netfilename;
   bool _usechains;
   int _bytesInDev;
 
