@@ -1,11 +1,9 @@
 //
-//  Copyright (c) 1996 by Massimiliano Ghilardi ( ghilardi@cibs.sns.it )
+//  Copyright (c) 1996, 2007 by Massimiliano Ghilardi ( ghilardi@cibs.sns.it )
 //
 //  This file may be distributed under terms of the GPL
 //
-//
-// $Id$
-//
+
 #ifndef _PAGEMETER_H_
 #define _PAGEMETER_H_
 
@@ -25,7 +23,7 @@ protected:
   int pageindex_;
   float maxspeed_;
   bool _vmstat;
-  char *_statFileName;
+  const char *_statFileName;
 
   void getpageinfo( void );
   void getvmpageinfo( void );
