@@ -7,8 +7,6 @@
 #include <unistd.h>
 #include <stdlib.h>
 #include <sys/time.h>
-#include "snprintf.h"
-#include "general.h"
 #include "xosview.h"
 #include "meter.h"
 #include "MeterMaker.h"
@@ -16,7 +14,7 @@
 #include "kernel.h"
 #endif
 
-static const char * const versionString = "xosview version: " XOSVIEW_VERSION;
+static const char * const versionString = "xosview version: Git";
 
 static const char NAME[] = "xosview@";
 
